@@ -5,7 +5,13 @@ import shutil
 from base64 import b64decode
 from contextlib import suppress
 from datetime import datetime
-from functools import partial, cached_property
+from functools import partial
+
+try:
+    from functools import cached_property
+except ImportError:
+    from .polyfill.cached_property import cached_property
+
 from http.cookiejar import Cookie
 from http.cookies import SimpleCookie
 from io import BytesIO
@@ -58,12 +64,14 @@ class ResponseBodyHandler:
         def __init__(self, *args, **kargs):
             JSONDecoder.__init__(self, *args, object_hook=_date_parser, **kargs)
 
-    def __init__(self):
-        try:
-            import brotli
-            self.SUPPORTED_COMPRESSION.insert(0, 'br')
-        except ImportError:
-            pass
+    def __init__(self, brotli:bool=True):
+
+        if brotli is True:
+            try:
+                import brotli
+                self.SUPPORTED_COMPRESSION.insert(0, 'br')
+            except ImportError:
+                pass
 
         self.content_encoding = ', '.join(self.SUPPORTED_COMPRESSION)
 
