@@ -19,12 +19,13 @@ class ScrapflyError(BaseException):
         'ERR::SCRAPE::TOO_MANY_CONCURRENT_REQUEST',
         'ERR::PROXY::RESOURCES_SATURATION',
         'ERR::PROXY::NOT_REACHABLE',
-        'ERR::PROXY::NETWORK_DOWN',
+        'ERR::PROXY::UNAVAILABLE',
         'ERR::THROTTLE::MAX_CONCURRENT_REQUEST_EXCEEDED',
         'ERR::THROTTLE::MAX_REQUEST_RATE_EXCEEDED',
         'ERR::SESSION::CONCURRENT_ACCESS',
         'ERR::ASP::SHIELD_EXPIRED',
-        'ERR::SCRAPE::NETWORK_ISSUE'
+        'ERR::SCRAPE::NETWORK_ISSUE',
+        'ERR::SCRAPE::DRIVER_TIMEOUT'
     ]
 
     KNOWN_HTTP_API_ERROR_CODE = [
